@@ -205,6 +205,8 @@ class SliceUpload(object):
         offset_next = offset + _BPUT_SIZE
         bput_next = readfile(inputfile, offset_next, _BPUT_SIZE)
         bputretry = bput_retries
+        bputcode = 200
+        bputtext = {'ctx' : ctx}
         while bput_next is not None and bputnum < _BLOCK_SIZE/_BPUT_SIZE:
             bputcode, bputtext = self.make_bput_post(ctx, bputnum, uploadBatch, bput_next)
             while bputretry and self.need_retry(bputcode):
